translate.convert.po2wordfast.wfmultifile

Package translate :: Package convert :: Module po2wordfast :: Class wfmultifile |
[hide private]
[frames] | no frames]

# Class wfmultifile

source code

Instance Methods | [hide private]
__init__(self, filename, mode=None) initialises wfmultifile from a seekable inputfile or writable outputfile | source code
openoutputfile(self, subfile) returns a pseudo-file object for the given subfile | source code